@@ -18,7 +18,7 @@
 #include <unistd.h>
 #include <dirent.h>
 
-__ID("@(#) $Id: cpufreq.cc 2336 2010-10-05 09:34:27Z lyonel $");
+__ID("@(#) $Id: cpufreq.cc 2470 2012-01-19 12:04:26Z lyonel $");
 
 #define DEVICESCPUFREQ "/sys/devices/system/cpu/cpu%d/cpufreq/"
 
@@ -69,7 +69,7 @@ bool scan_cpufreq(hwNode & node)
       cur = 1000*(unsigned long long)get_long("scaling_cur_freq");
       cpu->addCapability("cpufreq", "CPU Frequency scaling");
       if(cur) cpu->setSize(cur);
-      if(max>cpu->getCapacity()) cpu->setCapacity(cur);
+      if(max>cpu->getCapacity()) cpu->setCapacity(max);
       popd();
     }
     i++;
