@@ -9,7 +9,7 @@
 #include <stdlib.h>
 #include <vector>
 
-__ID("@(#) $Id: cpuinfo.cc 2433 2012-01-10 22:01:30Z lyonel $");
+__ID("@(#) $Id: cpuinfo.cc 2497 2012-05-20 00:03:55Z lyonel $");
 
 static int currentcpu = 0;
 
@@ -66,6 +66,13 @@ string value)
       cpu->setVersion(value);
     if (id == "cpu")
       cpu->setProduct(value);
+    if (id == "clock")
+    {
+      double frequency = 0.0;
+
+      frequency = atof(value.c_str());
+      cpu->setSize((unsigned long long) (frequency * 1E6));
+    }
   }
 }
 #endif
@@ -263,7 +270,7 @@ string value)
       cpu->setVendor(value);
     }
     if (id == "model name")
-      cpu->setProduct(value);
+      if(cpu->getProduct() == "") cpu->setProduct(value);
 //if ((id == "cpu MHz") && (cpu->getSize() == 0))
 //{
 //cpu->setSize((long long) (1000000L * atof(value.c_str())));
