@@ -21,7 +21,7 @@
 #include <unistd.h>
 #include <dirent.h>
 
-__ID("@(#) $Id: device-tree.cc 2433 2012-01-10 22:01:30Z lyonel $");
+__ID("@(#) $Id: device-tree.cc 2521 2013-05-08 13:43:30Z lyonel $");
 
 #define DIMMINFOSIZE 0x80
 typedef __uint8_t dimminfo_buf[DIMMINFOSIZE];
@@ -193,7 +193,8 @@ static void scan_devtree_cpu(hwNode & core)
       struct dirent **cachelist;
       int ncache;
 
-      if (hw::strip(get_string(basepath + "/device_type")) != "cpu")
+      if (exists(basepath + "/device_type") &&
+        hw::strip(get_string(basepath + "/device_type")) != "cpu")
         break;                                    // oops, not a CPU!
 
       cpu.setProduct(get_string(basepath + "/name"));
@@ -520,15 +521,15 @@ bool scan_device_tree(hwNode & n)
     core = n.getChild("core");
   }
 
-  n.setProduct(get_string(DEVICETREE "/model"));
+  n.setProduct(get_string(DEVICETREE "/model", n.getProduct()));
   n.addHint("icon", string("motherboard"));
 
-  n.setSerial(get_string(DEVICETREE "/serial-number"));
+  n.setSerial(get_string(DEVICETREE "/serial-number", n.getSerial()));
   if (n.getSerial() == "")
     n.setSerial(get_string(DEVICETREE "/system-id"));
   fix_serial_number(n);
 
-  n.setVendor(get_string(DEVICETREE "/copyright"));
+  n.setVendor(get_string(DEVICETREE "/copyright", n.getVendor()));
 
   get_apple_model(n);
 
