@@ -90,7 +90,7 @@
 #include <stdlib.h>
 #include <sys/mman.h>
 
-__ID("@(#) $Id: dmi.cc 2433 2012-01-10 22:01:30Z lyonel $");
+__ID("@(#) $Id: dmi.cc 2520 2013-05-08 13:32:48Z lyonel $");
 
 static int currentcpu = 0;
 
@@ -1039,7 +1039,8 @@ int dmiversionmin)
         if (dm->length >= 0x1B)
         {
           node.setConfig("sku", dmi_string(dm, data[0x19]));
-	  node.setProduct(node.getProduct() + " (" + dmi_string(dm, data[0x19]) + ")");
+	  if (dmi_string(dm, data[0x19]) != "")
+	    node.setProduct(node.getProduct() + " (" + dmi_string(dm, data[0x19]) + ")");
           node.setConfig("family", dmi_string(dm, data[0x1A]));
         }
         break;
@@ -1751,8 +1752,8 @@ bool scan_dmi(hwNode & n)
   u16 dmimaj = 0, dmimin = 0;
   currentcpu = 0;
 
-#ifdef __hppa__
-  return false;		// SMBIOS not supported on PA-RISC machines
+#if defined(__arm__) || defined (__hppa__) 
+  return false;		// SMBIOS not supported on PA-RISC and ARM machines
 #endif
 
   if (sizeof(u8) != 1 || sizeof(u16) != 2 || sizeof(u32) != 4)
