@@ -7,4 +7,7 @@ hwNode * guessParent(const hwNode & child, hwNode & base);
 
 string guessBusInfo(const string &);
 string guessParentBusInfo(const string &);
+bool guessVendor(hwNode & device);
+bool guessProduct(hwNode & device);
+
 #endif
