@@ -22,7 +22,7 @@
 
 using namespace hw;
 
-__ID("@(#) $Id: hw.cc 2336 2010-10-05 09:34:27Z lyonel $");
+__ID("@(#) $Id: hw.cc 2409 2011-08-24 16:17:26Z lyonel $");
 
 struct hwNode_i
 {
@@ -1654,6 +1654,10 @@ string hwNode::asXML(unsigned level)
   #endif
     if (geteuid() != 0)
       out << _("<!-- WARNING: not running as root -->") << endl;
+
+    if(::enabled("output:list"))
+      out << "<list>" << endl;
+
   }
 
   if(visible(getClassName()))
@@ -1929,6 +1933,10 @@ string hwNode::asXML(unsigned level)
     out << "</node>" << endl;
   }
 
+  if((level==0) && ::enabled("output:list"))
+    out << "</list>" << endl;
+
+
   return out.str();
 }
 
