@@ -36,7 +36,7 @@
 #include <sys/types.h>
 using namespace std;
 
-__ID("@(#) $Id: network.cc 2433 2012-01-10 22:01:30Z lyonel $");
+__ID("@(#) $Id: network.cc 2516 2013-02-03 16:43:25Z lyonel $");
 
 #ifndef ARPHRD_IEEE1394
 #define ARPHRD_IEEE1394 24
@@ -464,6 +464,10 @@ bool scan_network(hwNode & n)
             interface.setConfig("speed", "1Gbit/s");
             interface.setSize(1000000000L);
             break;
+          case SPEED_10000:
+            interface.setConfig("speed", "10Gbit/s");
+            interface.setSize(10000000000L);
+            break;
         }
         switch(ecmd.duplex)
         {
