@@ -31,7 +31,7 @@ std::string tostring(unsigned long long);
 std::string tohex(unsigned long long);
 std::string utf8(wchar_t);
 std::string utf8_sanitize(const std::string &);
-std::string utf8(uint16_t *s, size_t length = -1, bool forcelittleendian = false);
+std::string utf8(uint16_t *s, ssize_t length = -1, bool forcelittleendian = false);
 
 std::string spaces(unsigned int count, const std::string & space = " ");
 
