@@ -11,6 +11,7 @@
 #include "volumes.h"
 #include "blockio.h"
 #include "lvm.h"
+#include "fat.h"
 #include "osutils.h"
 #include <stdio.h>
 #include <sys/types.h>
@@ -21,7 +22,7 @@
 #include <stdint.h>
 #include <time.h>
 
-__ID("@(#) $Id: volumes.cc 2433 2012-01-10 22:01:30Z lyonel $");
+__ID("@(#) $Id: volumes.cc 2488 2012-02-22 00:23:47Z lyonel $");
 
 struct fstypes
 {
@@ -504,6 +505,7 @@ static bool detect_fat(hwNode & n, source & s)
   n.setSerial(dos_serial(serial));
   n.setDescription("");
 
+  scan_fat(n, fatvolume);
   return true;
 }
 
