@@ -2,27 +2,24 @@
 #include <unistd.h>
 #include <gtk/gtk.h>
 
-#include "interface.h"
 #include "support.h"
 #include "config.h"
 #include "stock.h"
 #include "engine.h"
 
-static char *id = "@(#) $Id: gtk-lshw.c 2336 2010-10-05 09:34:27Z lyonel $";
+static char *id = "@(#) $Id: gtk-lshw.c 2412 2011-08-31 16:46:41Z lyonel $";
 
-GtkWidget *mainwindow;
+extern GtkWidget *mainwindow;
 
 int
 main (int argc, char *argv[])
 {
-  GdkPixbuf *icon;
 #ifndef NONLS
   bindtextdomain (PACKAGE, LOCALEDIR);
   bind_textdomain_codeset (PACKAGE, "UTF-8");
   textdomain (PACKAGE);
 #endif
 
-  gtk_set_locale ();
   gtk_init (&argc, &argv);
 
   if(geteuid() != 0)
@@ -46,26 +43,12 @@ main (int argc, char *argv[])
   }
 
   lshw_gtk_stock_init();
+  lshw_ui_init();
 
-/*
- * The following code was added by Glade to create one of each component
- * (except popup menus), just so that you see something after building
- * the project. Delete any components that you don't want shown initially.
- */
-  mainwindow = create_lshw ();
-
-  icon = gtk_widget_render_icon(GTK_WIDGET(mainwindow),
-    "lshw-logo",
-    GTK_ICON_SIZE_DIALOG,
-    NULL);
-  if(GDK_IS_PIXBUF(icon))
-  {
-    gtk_window_set_icon(GTK_WINDOW(mainwindow), icon);
-    gtk_window_set_default_icon(icon);
-  }
-
-  gtk_widget_show (mainwindow);
+  if(!mainwindow)
+    return(1);
 
+  gtk_widget_show(mainwindow);
   gtk_main ();
 
   (void) &id;                                     // avoid warning "id defined but not used"
